==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/GeographicProportionalSymbolSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SizeScaleDescriptionMetadata } from "./SizeScaleDescriptionMetadata";
import { BrushScaleDescriptionMetadata } from "./BrushScaleDescriptionMetadata";
import { AssigningScatterStyleEventArgsDescriptionMetadata } from "./AssigningScatterStyleEventArgsDescriptionMetadata";
import { AssigningScatterMarkerStyleEventArgsDescriptionMetadata } from "./AssigningScatterMarkerStyleEventArgsDescriptionMetadata";
import { GeographicMarkerSeriesDescriptionMetadata } from "./GeographicMarkerSeriesDescriptionMetadata";
import { GeographicProportionalSymbolSeriesDescription } from "./GeographicProportionalSymbolSeriesDescription";
/**
 * @hidden
 */
export let GeographicProportionalSymbolSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class GeographicProportionalSymbolSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (GeographicProportionalSymbolSeriesDescriptionMetadata.a == null) {
                GeographicProportionalSymbolSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GeographicProportionalSymbolSeriesDescriptionMetadata.c(GeographicProportionalSymbolSeriesDescriptionMetadata.a);
            }
            if (a.k(GeographicProportionalSymbolSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ab(GeographicProportionalSymbolSeriesDescriptionMetadata.a);
            SizeScaleDescriptionMetadata.d(a);
            BrushScaleDescriptionMetadata.d(a);
            AssigningScatterStyleEventArgsDescriptionMetadata.d(a);
            AssigningScatterMarkerStyleEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            GeographicMarkerSeriesDescriptionMetadata.c(a);
            a.item("LatitudeMemberPath", "String");
            a.item("LongitudeMemberPath", "String");
            a.item("RadiusMemberPath", "String");
            a.item("RadiusScale", "ExportedType:SizeScale");
            a.item("LabelMemberPath", "String");
            a.item("FillMemberPath", "String");
            a.item("FillScale", "ExportedType:BrushScale");
            a.item("FillScaleUseGlobalValues", "Boolean");
            a.item("MarkerOutlineUsesFillScale", "Boolean");
            a.item("MarkerOutlineBrightness", "Number:double");
            a.item("MarkerBrushBrightness", "Number:double");
            a.item("RadiusScaleUseGlobalValues", "Boolean");
            a.item("IsCustomScatterStyleAllowed", "Boolean");
            a.item("IsCustomScatterMarkerStyleAllowed", "Boolean");
            a.item("ItemSearchMode", "ExportedType:string:ScatterItemSearchMode");
            a.item("ItemSearchMode@names", "Auto;ClosestVisiblePoint;ClosestPoint;ClosestVisiblePointOnClosestLine;ClosestPointOnClosestLine;None");
            a.item("ItemSearchThreshold", "Number:int");
            a.item("AssigningScatterStyleRef", "EventRef::assigningScatterStyle");
            a.item("AssigningScatterMarkerStyleRef", "EventRef::assigningScatterMarkerStyle");
        }
        static d(a) {
            GeographicProportionalSymbolSeriesDescriptionMetadata.b(a);
            a.ad("GeographicProportionalSymbolSeries", () => new GeographicProportionalSymbolSeriesDescription());
            a.ac("GeographicProportionalSymbolSeries", GeographicProportionalSymbolSeriesDescriptionMetadata.a);
        }
    }
    GeographicProportionalSymbolSeriesDescriptionMetadata.$t = markType(GeographicProportionalSymbolSeriesDescriptionMetadata, 'GeographicProportionalSymbolSeriesDescriptionMetadata');
    GeographicProportionalSymbolSeriesDescriptionMetadata.a = null;
    return GeographicProportionalSymbolSeriesDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/GeographicProportionalSymbolSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SizeScaleDescriptionMetadata } from "./SizeScaleDescriptionMetadata";
import { BrushScaleDescriptionMetadata } from "./BrushScaleDescriptionMetadata";
import { AssigningScatterStyleEventArgsDescriptionMetadata } from "./AssigningScatterStyleEventArgsDescriptionMetadata";
import { AssigningScatterMarkerStyleEventArgsDescriptionMetadata } from "./AssigningScatterMarkerStyleEventArgsDescriptionMetadata";
import { GeographicMarkerSeriesDescriptionMetadata } from "./GeographicMarkerSeriesDescriptionMetadata";
import { GeographicProportionalSymbolSeriesDescription } from "./GeographicProportionalSymbolSeriesDescription";
/**
 * @hidden
 */
export let GeographicProportionalSymbolSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class GeographicProportionalSymbolSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (GeographicProportionalSymbolSeriesDescriptionMetadata.a == null) {
                GeographicProportionalSymbolSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GeographicProportionalSymbolSeriesDescriptionMetadata.c(GeographicProportionalSymbolSeriesDescriptionMetadata.a);
            }
            if (a.k(GeographicProportionalSymbolSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ac(GeographicProportionalSymbolSeriesDescriptionMetadata.a);
            SizeScaleDescriptionMetadata.d(a);
            BrushScaleDescriptionMetadata.d(a);
            AssigningScatterStyleEventArgsDescriptionMetadata.d(a);
            AssigningScatterMarkerStyleEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            GeographicMarkerSeriesDescriptionMetadata.c(a);
            a.item("LatitudeMemberPath", "String");
            a.item("LongitudeMemberPath", "String");
            a.item("RadiusMemberPath", "String");
            a.item("RadiusScale", "ExportedType:SizeScale");
            a.item("LabelMemberPath", "String");
            a.item("FillMemberPath", "String");
            a.item("FillScale", "ExportedType:BrushScale");
            a.item("FillScaleUseGlobalValues", "Boolean");
            a.item("MarkerOutlineUsesFillScale", "Boolean");
            a.item("MarkerOutlineBrightness", "Number:double");
            a.item("MarkerBrushBrightness", "Number:double");
            a.item("RadiusScaleUseGlobalValues", "Boolean");
            a.item("IsCustomScatterStyleAllowed", "Boolean");
            a.item("IsCustomScatterMarkerStyleAllowed", "Boolean");
            a.item("ItemSearchMode", "ExportedType:string:ScatterItemSearchMode");
            a.item("ItemSearchMode@names", "Auto;ClosestVisiblePoint;ClosestPoint;ClosestVisiblePointOnClosestLine;ClosestPointOnClosestLine;TopVisiblePoint;None");
            a.item("ItemSearchThreshold", "Number:int");
            a.item("AssigningScatterStyleRef", "EventRef::assigningScatterStyle");
            a.item("AssigningScatterMarkerStyleRef", "EventRef::assigningScatterMarkerStyle");
        }
        static d(a) {
            GeographicProportionalSymbolSeriesDescriptionMetadata.b(a);
            a.ae("GeographicProportionalSymbolSeries", () => new GeographicProportionalSymbolSeriesDescription());
            a.ad("GeographicProportionalSymbolSeries", GeographicProportionalSymbolSeriesDescriptionMetadata.a);
        }
    }
    GeographicProportionalSymbolSeriesDescriptionMetadata.$t = markType(GeographicProportionalSymbolSeriesDescriptionMetadata, 'GeographicProportionalSymbolSeriesDescriptionMetadata');
    GeographicProportionalSymbolSeriesDescriptionMetadata.a = null;
    return GeographicProportionalSymbolSeriesDescriptionMetadata;
})();
